# Project Contributors

This project was started in 2017 by [Leonardo Uieda](http://www.leouieda.com)
during [an NSF funded postdoc](http://www.leouieda.com/blog/hawaii-gmt-postdoc.html)
with [Paul Wessel](http://www.soest.hawaii.edu/wessel) at the University of Hawaii at
Manoa.

The following people have contributed code to the project (alphabetical by last name)
and are considered the "PyGMT Developers":

* [Wei Ji Leong](https://github.com/weiji14)
* [Tyler Newton](http://www.tnewton.com/)
* [Dongdong Tian](https://seisman.info/)
* [Liam Toney](https://liam.earth/)
* [Leonardo Uieda](http://www.leouieda.com/)
